presentationData property
This will be need to show the data in the form of presentation
Implementation
final List<PresentationData> presentationData;
This will be need to show the data in the form of presentation
final List<PresentationData> presentationData;