PresentationData class

Constructors

PresentationData({required String title, required String imgSrc, String? detailText, String? youtubeLink, String? imageMode, List<PresentationData>? subCategories})

Properties

detailText String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageMode String?
getter/setter pair
imgSrc String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subCategories List<PresentationData>?
getter/setter pair
title String
getter/setter pair
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) PresentationData
fromJsonList(List list) List<PresentationData>
toJson(PresentationData model) Map<String, dynamic>
toJsonList(List<PresentationData> list) List<Map<String, dynamic>>