EasyPresentationApp class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- EasyPresentationApp
Constructors
-
EasyPresentationApp({Key? key, required List<
PresentationData> presentationData, String? title, String? leadingTitle, String? bgImage, MarkdownStyleSheet? markdownStyleSheet, bool topSafeArea = true, EventActionCallback? onTapEvent, PlacementBuilder? placementBuilder}) -
const
Properties
- bgImage → String?
-
This will be added as a background image with blur effect
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leadingTitle → String?
-
This leadingTitle will be added before main title
final
- markdownStyleSheet → MarkdownStyleSheet?
-
Use this to add your custom
MarkdownStyleSheetfinal - onTapEvent → EventActionCallback?
-
onTapEvent will be call on every event preformed by the user
final
- placementBuilder → PlacementBuilder?
-
placementBuilder is used to build your custom widget at specific places
final
-
presentationData
→ List<
PresentationData> -
This will be need to show the data in the form of presentation
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
This is the main title text
final
- topSafeArea → bool
-
This is for safe area space
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
launchApp(
BuildContext context, {String? leadingTitle, String? title, String? bgImage, bool topSafeArea = true, required List< PresentationData> presentationData, MarkdownStyleSheet? markdownStyleSheet, EventActionCallback? onTapEvent, PlacementBuilder? placementBuilder}) → void