launchApp static method
void
launchApp(
- BuildContext context, {
- String? leadingTitle,
- String? title,
- String? bgImage,
- bool topSafeArea = true,
- required List<
PresentationData> presentationData, - MarkdownStyleSheet? markdownStyleSheet,
- EventActionCallback? onTapEvent,
- PlacementBuilder? placementBuilder,
Implementation
static void launchApp(
BuildContext context, {
/// This [leadingTitle] will be added before main [title]
final String? leadingTitle,
/// This is the main title text
final String? title,
/// This will be added as a background image with blur effect
final String? bgImage,
/// This is for safe area space
final bool topSafeArea = true,
/// This will be need to show the data in the form of presentation
required final List<PresentationData> presentationData,
/// Use this to add your custom [MarkdownStyleSheet]
final MarkdownStyleSheet? markdownStyleSheet,
/// [onTapEvent] will be call on every event preformed by the user
final EventActionCallback? onTapEvent,
/// [placementBuilder] is used to build your custom widget at specific places
final PlacementBuilder? placementBuilder,
}) => Navigator.of(context).push(
MaterialPageRoute(
fullscreenDialog: true,
builder: (context) => Scaffold(
body: EasyPresentationApp(
leadingTitle: leadingTitle,
title: title,
bgImage: bgImage,
topSafeArea: topSafeArea,
presentationData: presentationData,
markdownStyleSheet: markdownStyleSheet,
onTapEvent: onTapEvent,
placementBuilder: placementBuilder,
),
),
),
);